==> lsst_daf_butler-26.2023.4600-py3-none-any.whl: lsst/daf/butler/remote_butler/server/_config.py <==
# This file is part of daf_butler.
#
# Developed for the LSST Data Management System.
# This product includes software developed by the LSST Project
# (http://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This software is dual licensed under the GNU General Public License and also
# under a 3-clause BSD license. Recipients may choose which of these licenses
# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
# respectively.  If you choose the GPL option then the following text applies
# (but note that there is still no warranty even if you opt for BSD instead):
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
from dataclasses import dataclass

__all__ = ("Config", "get_config_from_env")


@dataclass(frozen=True)
class Config:
    config_uri: str


def get_config_from_env() -> Config:
    config_uri = os.getenv("BUTLER_SERVER_CONFIG_URI")
    if config_uri is None:
        raise Exception(
            "The environment variable BUTLER_SERVER_CONFIG_URI "
            "must point to a Butler configuration to be used by the server"
        )
    return Config(config_uri=config_uri)

==> lsst_daf_butler-26.2023.5100-py3-none-any.whl: lsst/daf/butler/remote_butler/server/_config.py <==
# This file is part of daf_butler.
#
# Developed for the LSST Data Management System.
# This product includes software developed by the LSST Project
# (http://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This software is dual licensed under the GNU General Public License and also
# under a 3-clause BSD license. Recipients may choose which of these licenses
# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
# respectively.  If you choose the GPL option then the following text applies
# (but note that there is still no warranty even if you opt for BSD instead):
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
from dataclasses import dataclass

__all__ = ("Config", "get_config_from_env")


@dataclass(frozen=True)
class Config:
    """Simplified configuration for a client/server connection."""

    config_uri: str
    """URI of the configuration."""


def get_config_from_env() -> Config:
    """Retrieve a configuration from the environment."""
    config_uri = os.getenv("BUTLER_SERVER_CONFIG_URI")
    if config_uri is None:
        raise Exception(
            "The environment variable BUTLER_SERVER_CONFIG_URI "
            "must point to a Butler configuration to be used by the server"
        )
    return Config(config_uri=config_uri)
